" Vim syntax file
" Language:     Csound unified file (CSD)
" Maintainer:   Istvan Varga
" Last change:  Jan 6 2003

syn	clear

set	nocompatible
set	autoindent
set	noignorecase
set	showmatch

set	keywordprg=cshelp

" reserved variables (sr etc.) and opcodes

syn	keyword	Identifier	sr kr ksmps nchnls 0dbfs
syn	keyword	Statement	instr endin opcode endop
syn	keyword	Statement	if then else elseif endif

" score statements (f, t, i etc.)

syn	match	Statement	"^[ \t]*[[:alpha:]]\>"

" CSD tags

hi	link	CSDTag		Statement

syn	keyword	CSDTag		CsoundSynthesizer
syn	keyword	CSDTag		CsVersion
syn	keyword	CSDTag		CsOptions
syn	keyword	CSDTag		CsInstruments
syn	keyword	CSDTag		CsScore
syn	keyword	CSDTag		CsMidifile
syn	keyword	CSDTag		CsMidifileB
syn	keyword	CSDTag		CsSampleB
syn	keyword	CSDTag		CsFileB

syn	match	Identifier	"<[[:alnum:]]\+>" contains=CSDTag
syn	match	Identifier	"</[[:alnum:]]\+>" contains=CSDTag

" set installation directory here

source	__SYNDIR__/Csound_opcodes.vim

" comments

syn	region	Comment	start="/\*" end="\*/"
syn	match	Comment ";.*$"

" backslash

syn	match	Special	"\\$"
syn	match	Special "\\."

" labels

syn	match	Label		"^[[:space:]]*[[:alnum:]_]\+:"

" variable types

syn	match	Type	"\<[akip]"
syn	match	Type	"\<g[aki]"

" constants

syn	match	Constant	"\<[[:digit:]]\+\(\.[[:digit:]]\+\)\{,1\}\([Ee][+-]\{,1\}[[:digit:]]\+\)\{,1\}\>"
syn	match	Constant	"\".*\""

" include files and macros

syn	match	PreProc	"#"
syn	match	PreProc	"#include"
syn	match	PreProc	"#define"
syn	match	PreProc	"#define[^#]*#"
syn	match	PreProc	"#undef.*$"
syn	match	PreProc	"\$[[:alpha:]][[:alnum:]_]*\(([^()]*)\)\{,1\}\.\{,1\}"

" some useful keyboard shortcuts

" ``c: insert CSD template

imap	``c	<CsoundSynthesizer><CR><CsInstruments><CR><CR></CsInstruments><CR><CsScore><CR><CR></CsScore><CR></CsoundSynthesizer><CR><UP><UP><UP><UP><UP><UP>

" ``o: insert CSD options

imap	``o	<CsOptions><CR><CR></CsOptions><CR><UP><UP>

" ``v: insert CSD version

imap	``v	<CsVersion><CR><CR></CsVersion><CR><UP><UP>

" F1: orchestra header (mono)

imap	<F1>	sr<TAB>=  48000<CR>ksmps<TAB>=  32<CR>nchnls<TAB>=  1<CR>0dbfs<TAB>=  1<CR><CR>

" F2: orchestra header (stereo)

imap	<F2>	sr<TAB>=  48000<CR>ksmps<TAB>=  32<CR>nchnls<TAB>=  2<CR>0dbfs<TAB>=  1<CR><CR>

" F4: orchestra header (quad)

imap	<F4>	sr<TAB>=  48000<CR>ksmps<TAB>=  32<CR>nchnls<TAB>=  4<CR>0dbfs<TAB>=  1<CR><CR>

" ``1 ... ``9: instrument templates (instr 1 ... 9)

imap	``1	<TAB>instr 1<CR><HOME><DEL><CR><TAB>endin<CR><HOME><DEL><UP><UP>
imap	``2	<TAB>instr 2<CR><HOME><DEL><CR><TAB>endin<CR><HOME><DEL><UP><UP>
imap	``3	<TAB>instr 3<CR><HOME><DEL><CR><TAB>endin<CR><HOME><DEL><UP><UP>
imap	``4	<TAB>instr 4<CR><HOME><DEL><CR><TAB>endin<CR><HOME><DEL><UP><UP>
imap	``5	<TAB>instr 5<CR><HOME><DEL><CR><TAB>endin<CR><HOME><DEL><UP><UP>
imap	``6	<TAB>instr 6<CR><HOME><DEL><CR><TAB>endin<CR><HOME><DEL><UP><UP>
imap	``7	<TAB>instr 7<CR><HOME><DEL><CR><TAB>endin<CR><HOME><DEL><UP><UP>
imap	``8	<TAB>instr 8<CR><HOME><DEL><CR><TAB>endin<CR><HOME><DEL><UP><UP>
imap	``9	<TAB>instr 9<CR><HOME><DEL><CR><TAB>endin<CR><HOME><DEL><UP><UP>

" ``p: opcode template

imap	``p	<TAB>opcode , ,<CR><HOME><DEL><CR>;<TAB>setksmps 1<CR>;<TAB>xin<CR><CR>;<TAB>xout<CR><CR><TAB>endop<CR><HOME><DEL><UP><UP><UP><UP><UP><UP><UP><UP><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT>

" #i: include file

imap	#i	#include ""<CR><UP><HOME><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT>

" #d: define macro

imap	#d	#define  # #<CR><UP><HOME><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT>

" #u: undefine macro

imap	#u	#undef <CR><UP><HOME><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT><RIGHT>

" some opcodes

imap	`a	ampdbfs()<SPACE><LEFT><LEFT>
imap	`b	butterlp<SPACE>
imap	`c	clfilt<SPACE>
imap	`d	delay<SPACE>
imap	`e	expseg<SPACE>
imap	`f	ftgen<SPACE>
imap	`g	grain3<SPACE>
imap	`h	hilbert<SPACE>
imap	`i	interp<SPACE>
imap	`l	linseg<SPACE>
imap	`m	massign<SPACE>
imap	`n	nstrnum<SPACE>
imap	`o	oscilikt<SPACE>
imap	`p	printks<SPACE>
imap	`r	rbjeq<SPACE>
imap	`s	soundin<SPACE>
imap	`t	table<SPACE>
imap	`u	upsamp<SPACE>
imap	`v	vco2ft<SPACE>
imap	`w	wrap<SPACE>
imap	`x	xtratim<SPACE>

" ``f: insert dummy score

imap	``f	<CR>f 0 3600<CR>e<CR>

