#!/bin/bash

# install script for Csound VIM syntax files and help viewer program
# written by Istvan Varga, Jan 2003

if [ "${UID}" != "0" ] ; then
	echo -e "This installation script must be run as root."
	exit -1 ;
fi

# select installation directories

SYNDIR="/usr/local/share/vim/syntax"
DOCDIR="/Csound/Documentation"
VIEWPRG="lynx"
BINDIR="/usr/local/bin"

echo -e "Installation directory for syntax files (default: ${SYNDIR}):"
read TMP
TMP=`echo -e "$TMP" | tr -d " \t\r\n"`
if [ "$TMP" != "" ] ; then SYNDIR="${TMP}" ; fi

echo -e "Documentation base directory (default: ${DOCDIR}):"
read TMP
TMP=`echo -e "$TMP" | tr -d " \t\r\n"`
if [ "$TMP" != "" ] ; then DOCDIR="${TMP}" ; fi

ACRMDIR="${DOCDIR}/manual"
MISCDIR="${DOCDIR}/misc"

echo -e "Alternative Csound Reference Manual directory (default: ${ACRMDIR}):"
read TMP
TMP=`echo -e "$TMP" | tr -d " \t\r\n"`
if [ "$TMP" != "" ] ; then ACRMDIR="${TMP}" ; fi

echo -e "Directory for additional documentation (default: ${MISCDIR}):"
read TMP
TMP=`echo -e "$TMP" | tr -d " \t\r\n"`
if [ "$TMP" != "" ] ; then MISCDIR="${TMP}" ; fi

echo -e "Installation directory for cshelp script (default: ${BINDIR}):"
read TMP
TMP=`echo -e "$TMP" | tr -d " \t\r\n"`
if [ "$TMP" != "" ] ; then BINDIR="${TMP}" ; fi

echo -e "Documentation viewer program (default: ${VIEWPRG}):"
read TMP
TMP=`echo -e "$TMP" | tr -d " \t\r\n"`
if [ "$TMP" != "" ] ; then VIEWPRG="${TMP}" ; fi

# confirm settings

echo -e "\nInstallation settings:"
echo -e "  Installation directory for syntax files: ${SYNDIR}"
echo -e "  Documentation base directory: ${DOCDIR}"
echo -e "  Alternative Csound Reference Manual directory: ${ACRMDIR}"
echo -e "  Directory for additional documentation: ${MISCDIR}"
echo -e "  Installation directory for cshelp script: ${BINDIR}"
echo -e "  Documentation viewer program: ${VIEWPRG}"
echo -e "Are these correct (type y to continue installation): "
read TMP
if [ "$TMP" != "y" ] ; then
	echo -e "Installation aborted."
	exit 0 ;
fi
echo -e ""

# create new vimrc file

if [ -e "/etc/vimrc" ] ; then
	cat "/etc/vimrc"						|    \
	grep -v -e '" enable syntax highlighting'			|    \
	grep -v -e '^[[:space:]]*syntax[[:space:]]\+enable'		|    \
	grep -v -e '" set syntax for Csound files'			|    \
	grep -v -i -e '^[[:space:]]*au.*\<BufNewFile\>.*[[:space:]]\+\*\.csd\>'										|    \
	grep -v -i -e '^[[:space:]]*au.*\<BufRead\>.*[[:space:]]\+\*\.csd\>'										|    \
	grep -v -i -e '^[[:space:]]*au.*\<BufNewFile\>.*[[:space:]]\+\*\.orc\>'										|    \
	grep -v -i -e '^[[:space:]]*au.*\<BufRead\>.*[[:space:]]\+\*\.orc\>'										|    \
	grep -v -i -e '^[[:space:]]*au.*\<BufNewFile\>.*[[:space:]]\+\*\.sco\>'										|    \
	grep -v -i -e '^[[:space:]]*au.*\<BufRead\>.*[[:space:]]\+\*\.sco\>'										>    \
	"/tmp/__csvimsyntax_inst.vim" ;
else
	echo -e -n "" > "/tmp/__csvimsyntax_inst.vim" ;
fi
cat "./vimrc" | sed "s'__SYNDIR__'${SYNDIR}'" >> "/tmp/__csvimsyntax_inst.vim"

# confirm modifications to /etc/vimrc

echo -e "A new /etc/vimrc file was created. Check if the modifications are"
echo -e "correct (the new file will be displayed in a few seconds)."
sleep 4
if ( which vim > /dev/null 2>&1 ) ; then
	vim "/tmp/__csvimsyntax_inst.vim" ;
elif ( which vi > /dev/null 2>&1 ) ; then
	vi "/tmp/__csvimsyntax_inst.vim" ;
else
	cat "/tmp/__csvimsyntax_inst.vim" ;
fi
echo -e "\nType y to accept changes to /etc/vimrc and finish installation: "
read TMP
if [ "$TMP" != "y" ] ; then
	echo -e "Installation aborted."
	rm -f "/tmp/__csvimsyntax_inst.vim"
	exit 0 ;
fi

# create installation directories

umask 022

mkdir -p -m 0755 "${SYNDIR}"		|| exit -1
mkdir -p -m 0755 "${DOCDIR}"		|| exit -1
mkdir -p -m 0755 "${BINDIR}"		|| exit -1
mkdir -p -m 0755 "${ACRMDIR}"		|| exit -1
mkdir -p -m 0755 "${MISCDIR}"		|| exit -1

# ---- copy files ----

# help viewer
rm -f "${BINDIR}/cshelp"
cat cshelp | sed "s'__DOCDIR__'${DOCDIR}'" | sed "s'__DOC_VIEWER__'${VIEWPRG}'" > "${BINDIR}/cshelp"
chmod 0755 "${BINDIR}/cshelp"

# syntax files
install -p -m 0644 Csound_opcodes.vim Csound_sco.vim "${SYNDIR}"

for i in Csound_csd.vim Csound_orc.vim ; do
	rm -f "${SYNDIR}/$i"
	cat "$i" | sed "s'__SYNDIR__'${SYNDIR}'" > "${SYNDIR}/$i"
	chmod 0644 "${SYNDIR}/$i" ;
done

# help viewer index
rm -f "${DOCDIR}/cshelp.txt"
cat cshelp.txt | sed "s'__ACRM_DIR__'${ACRMDIR}'" | sed "s'__MISC_DIR__'${MISCDIR}'" > "${DOCDIR}/cshelp.txt"
chmod 0644 "${DOCDIR}/cshelp.txt"

# additional documentation files
install -p -m 0644 misc/*.txt "${MISCDIR}"

# vimrc
rm -f "/etc/vimrc"
install -p -m 0644 "/tmp/__csvimsyntax_inst.vim" "/etc/vimrc"
rm -f "/tmp/__csvimsyntax_inst.vim"

