#!/bin/bash

# set Alternative Csound Reference Manual directory

ACRMDIR="/Csound/Documentation/manual"

echo -e -n "Manual directory (default: ${ACRMDIR}): "
read TMP
TMP=`echo -e "$TMP" | tr -d " \t\r\n"`
if [ "$TMP" != "" ] ; then ACRMDIR="$TMP" ; fi

if ( ! ( [ -e "${ACRMDIR}/genindex.html" ] ) ) ; then
	echo -e "${ACRMDIR}: cannot find manual in this directory"
	exit -1 ;
fi

# create opcode list

if ( which csoundfltk > /dev/null 2>&1 ) ; then
	CSND=csoundfltk ;
elif ( which csound > /dev/null 2>&1 ) ; then
	CSND=csound ;
else
	echo -e "Cannot find Csound executable"
	exit -1 ;
fi

OPCODELIST=`${CSND} -z1 2>/dev/null | grep -e "^[[:alpha:]]" |		\
	    tr "\t" " " | cut -d " " -f 1 | uniq`

# extract opcode names from manual files

TEMP_DIR="/tmp/__makerefs_$$"
rm -Rf "${TEMP_DIR}"
mkdir -p -m 0700 "${TEMP_DIR}"

for i in ${ACRMDIR}/*.htm* ; do
	cat "$i" | grep -A6 -e '\<REFNAMEDIV\>' | grep -e '--' |	\
	sed 's/^[^[:alpha:]]*\([[:alnum:][:space:]_,]\+\).*$/\1/' >	\
	${TEMP_DIR}/`basename $i` ;
done
# remove empty files
rm -f `find "${TEMP_DIR}" -type f -size 0 -print`

# create opcode reference

rm -f "cshelp.txt.in"
for j in $OPCODELIST ; do
	FNAMES=`grep -l -e "\<$j\>" ${TEMP_DIR}/*.htm* |		\
		tr " " "\n" | tr "\t" "\n" | tr "\r" "\n"`
	NR_FNAMES=`echo -e "$FNAMES" | wc -w | tr -d " \t\r\n"`
	if [ "$NR_FNAMES" == "0" ] ; then
		echo -e "WARNING: no manual was found for $j" ;
	else
		if [ "$NR_FNAMES" != "1" ] ; then
			echo -e "WARNING: multiple files for opcode $j:"
			echo -e "$FNAMES" | tr -s "\n" ;
		fi
		FNAME=`echo -e "$FNAMES" | grep -v -e "^$" |		\
		       head -n 1 | tr -d "\n"`
		echo -e $j:__ACRM_DIR__/`basename $FNAME` >> "cshelp.txt.in" ;
	fi ;
done

rm -Rf "${TEMP_DIR}"

